# dora-sam2

> [!WARNING]  
> SAM2 requires Nvidia GPU to be able to run.

## Getting started

- Install it with pip:

```bash
pip install -e .
```

## Contribution Guide

- Format with [ruff](https://docs.astral.sh/ruff/):

```bash
ruff check . --fix
```

- Lint with ruff:

```bash
ruff check .
```

- Test with [pytest](https://github.com/pytest-dev/pytest)

```bash
pytest . # Test
```

## YAML Specification

## Examples

## License

dora-sam2's code are released under the MIT License
